//
//  TweetCellController.m
//  TestTwitterClient
//
//  Created by Akabeko on 11/09/24.
//  Copyright 2011, Akabeko. All rights reserved.
//

#import "TweetCellController.h"

////////////////////////////////////////////////////////////////////////////////
#pragma mark - TweetCell

@implementation TweetCell

@synthesize icon;
@synthesize name;
@synthesize tweet;
@synthesize date;

/**
 * メモリを解放します。
 */
- (void)dealloc
{
    [_iconImgeView release];
    [_nameLabel    release];
    [_tweetLabel   release];
    [_dateLabel    release];
    
    [super dealloc];
}

/**
 * セルの高さを算出します。
 *
 * @param text 算出基準となるテキスト。
 *
 * @return 高さ。
 */
+ (CGFloat)calcHeight:(NSString*)text
{
    const CGFloat defaultCellHeight = 86;
    const CGFloat defaultTextHeight = 21;
    
    UIFont* font     = [UIFont systemFontOfSize:14];
    CGSize  size     = CGSizeMake( 224, 1000 );
    CGSize  textSize = [text sizeWithFont:font constrainedToSize:size lineBreakMode:UILineBreakModeCharacterWrap];
 
    return defaultCellHeight + ( textSize.height - defaultTextHeight );
}

#pragma mark Propety methods

/**
 * アイコン画像を取得します。
 *
 * @return 画像。
 */
- (UIImage *)icon { return _iconImgeView.image; }

/**
 * アイコン画像を設定します。
 *
 * @param value 画像。
 */
- (void)setIcon:(UIImage *)value
{

    _iconImgeView.image = value;
}

/**
 * ユーザー名テキストを取得します。
 *
 * @return テキスト。
 */
- (NSString *)name { return _nameLabel.text; }

/**
 * ユーザー名テキストを設定します。
 *
 * @param value テキスト。
 */
- (void)setName:(NSString *)value { _nameLabel.text = value; }

/**
 * つぶやきテキストを取得します。
 *
 * @return テキスト。
 */
- (NSString *)tweet { return _tweetLabel.text; }

/**
 * つぶやきテキストを設定します。
 *
 * @param value テキスト。
 */
- (void)setTweet:(NSString *)value { _tweetLabel.text = value; }

/**
 * 日時テキストを取得します。
 *
 * @return テキスト。
 */
- (NSString *)date { return _dateLabel.text; }

/**
 * 日時テキストを設定します。
 *
 * @param value テキスト。
 */
- (void)setDate:(NSString *)value { _dateLabel.text = value; }

@end

////////////////////////////////////////////////////////////////////////////////
#pragma mark - TweetCellController

@implementation TweetCellController

/**
 * View が読み込まれる時に発生します。
 */
- (void)viewDidLoad
{
    [super viewDidLoad];
}

/**
 * View が破棄される時に発生します。
 */
- (void)viewDidUnload
{
    [_cell release];
    _cell = nil;
    
    [super viewDidUnload];
}

/**
 * メモリを解放します。
 */
- (void)dealloc
{
    [_cell release];
    
    [super dealloc];
}


@end
